# Identity library

This is an authentication/authorization library, currently optimized for web apps.
It provides some higher level APIs built on top of
[Microsoft's MSAL Python](https://github.com/AzureAD/microsoft-authentication-library-for-python).

## Scenarios supported

* Web app that signs in users
* Web app that signs in users and calls a web API on their behalf
* Protected web API that only authenticated users can access (Partial support)
* [In roadmap] Protected web API that calls another (downstream) web API on behalf of the signed-in user

## Installation

TBD


## Versions

This library follows [Semantic Versioning](http://semver.org/).

You can find the changes for each version under
[Releases](https://github.com/rayluo/identity/releases).


## Usage

Sample coming soon.

